.. _api_dul_pdu_aabortrq:

A-ABORT-RQ PDU
==============

.. currentmodule:: pynetdicom.pdu

An A-ABORT-RQ PDU is made of a sequence of mandatory fields and supports both
the A-ABORT Service (user initiated) and the A-P-ABORT Service (provider
initiated).

PDU
---

.. autosummary::
   :toctree: generated/

   A_ABORT_RQ
